# mimodulito

Make the **modulus** part of your life style! 

<!-- This are visual tags that you may add to your package at the beginning with useful information on your package --> 
[![version](https://img.shields.io/pypi/v/mimodulito?color=blue)](https://pypi.org/project/mimodulito/)
[![downloads](https://img.shields.io/pypi/dw/mimodulito)](https://pypi.org/project/mimodulito/)


**MiModulito** is a package that allouds you to perform the modulus operation between two numbers like you've never seen before. It's efficency will leave you astonished.

<p align="center"><img src="https://drive.google.com/uc?export=view&id=1F0h24lFKx-nD_jZi-H3Qv1xVfisGBVJN" alt="Logo""/></p>

## Download and install

If you are using `PyPI` installation it's as simple as:

```
pip install mimodulito
```

You can also test the unstable version of the package with:

```
pip install -i https://test.pypi.org/simple/ mimodulito
```

## Quick start

To import the package, run the next command:

```
import mimodulito
```

## Code examples

Lets calculate the operation 3%2 usind the `mod` function:

```
import mimodulito
print(mimodulito.mod(3,2))
```

## What's new

Version 0.4:

- Corrections in main function.

Version 0.3:

- Corrections in stability.

Version 0.2:

- Function `mod` was implemented.

Version 0.1:

- First version of the package.

------------

This package has been designed and written by Daniel Niño Villegas (C) 2023